==> haskell-resolv-0.2.0.3-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-resolv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 resolv
version:              0.2.0.3
visibility:           public
id:                   resolv-0.2.0.3-JaFuypxValtLsjY0IKGRkf
key:                  resolv-0.2.0.3-JaFuypxValtLsjY0IKGRkf
license:              GPL-2.0-or-later
maintainer:           Alexey Radkov, Andreas Abel
author:               Herbert Valerio Riedel
synopsis:
    Domain Name Service (DNS) lookup via the libresolv standard library routines

description:
    This package implements an API for accessing
    the [Domain Name Service (DNS)](https://tools.ietf.org/html/rfc1035)
    resolver service via the standard @libresolv@ system library (whose
    API is often available directly via the standard @libc@ C library) on
    Unix systems.

    This package also includes support for decoding message record types
    as defined in the following RFCs:

    - [RFC 1035](https://tools.ietf.org/html/rfc1035): Domain Names - Implementation And Specification
    - [RFC 1183](https://tools.ietf.org/html/rfc1183): New DNS RR Definitions
    - [RFC 2782](https://tools.ietf.org/html/rfc2782): A DNS RR for specifying the location of services (DNS SRV)
    - [RFC 2915](https://tools.ietf.org/html/rfc2915): The Naming Authority Pointer (NAPTR) DNS Resource Record
    - [RFC 3596](https://tools.ietf.org/html/rfc3596): DNS Extensions to Support IP Version 6
    - [RFC 4034](https://tools.ietf.org/html/rfc4034): Resource Records for the DNS Security Extensions
    - [RFC 4255](https://tools.ietf.org/html/rfc4255): Using DNS to Securely Publish Secure Shell (SSH) Key Fingerprints
    - [RFC 4408](https://tools.ietf.org/html/rfc4408): Sender Policy Framework (SPF) for Authorizing Use of Domains in E-Mail, Version 1
    - [RFC 5155](https://tools.ietf.org/html/rfc5155): DNS Security (DNSSEC) Hashed Authenticated Denial of Existence
    - [RFC 6844](https://tools.ietf.org/html/rfc6844): DNS Certification Authority Authorization (CAA) Resource Record
    - [RFC 6891](https://tools.ietf.org/html/rfc6891): Extension Mechanisms for DNS (EDNS(0))
    - [RFC 7553](https://tools.ietf.org/html/rfc7553): The Uniform Resource Identifier (URI) DNS Resource Record

    For Windows, the package [windns](https://hackage.haskell.org/package/windns)
    provides a compatible subset of this package'\''s API.

category:             Network
abi:                  e72b091fc9bc08823707a117b82f4ac5
exposed:              True
exposed-modules:      Network.DNS
hidden-modules:       Network.DNS.Message Network.DNS.FFI Compat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/resolv-0.2.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/resolv-0.2.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/resolv-0.2.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-resolv
hs-libraries:         HSresolv-0.2.0.3-JaFuypxValtLsjY0IKGRkf
depends:
    base-4.17.2.1 base16-bytestring-1.0.2.0-8cYMJjJ2evUJdToLJsrqX6
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7

haddock-interfaces:   /usr/share/doc/haskell-resolv/html/resolv.haddock
haddock-html:         /usr/share/doc/haskell-resolv/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resolv-0.2.0.3-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-resolv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 resolv
version:              0.2.0.3
visibility:           public
id:                   resolv-0.2.0.3-6GogbJI66nX3ijEU5qmLzY
key:                  resolv-0.2.0.3-6GogbJI66nX3ijEU5qmLzY
license:              GPL-2.0-or-later
maintainer:           Alexey Radkov, Andreas Abel
author:               Herbert Valerio Riedel
synopsis:
    Domain Name Service (DNS) lookup via the libresolv standard library routines

description:
    This package implements an API for accessing
    the [Domain Name Service (DNS)](https://tools.ietf.org/html/rfc1035)
    resolver service via the standard @libresolv@ system library (whose
    API is often available directly via the standard @libc@ C library) on
    Unix systems.

    This package also includes support for decoding message record types
    as defined in the following RFCs:

    - [RFC 1035](https://tools.ietf.org/html/rfc1035): Domain Names - Implementation And Specification
    - [RFC 1183](https://tools.ietf.org/html/rfc1183): New DNS RR Definitions
    - [RFC 2782](https://tools.ietf.org/html/rfc2782): A DNS RR for specifying the location of services (DNS SRV)
    - [RFC 2915](https://tools.ietf.org/html/rfc2915): The Naming Authority Pointer (NAPTR) DNS Resource Record
    - [RFC 3596](https://tools.ietf.org/html/rfc3596): DNS Extensions to Support IP Version 6
    - [RFC 4034](https://tools.ietf.org/html/rfc4034): Resource Records for the DNS Security Extensions
    - [RFC 4255](https://tools.ietf.org/html/rfc4255): Using DNS to Securely Publish Secure Shell (SSH) Key Fingerprints
    - [RFC 4408](https://tools.ietf.org/html/rfc4408): Sender Policy Framework (SPF) for Authorizing Use of Domains in E-Mail, Version 1
    - [RFC 5155](https://tools.ietf.org/html/rfc5155): DNS Security (DNSSEC) Hashed Authenticated Denial of Existence
    - [RFC 6844](https://tools.ietf.org/html/rfc6844): DNS Certification Authority Authorization (CAA) Resource Record
    - [RFC 6891](https://tools.ietf.org/html/rfc6891): Extension Mechanisms for DNS (EDNS(0))
    - [RFC 7553](https://tools.ietf.org/html/rfc7553): The Uniform Resource Identifier (URI) DNS Resource Record

    For Windows, the package [windns](https://hackage.haskell.org/package/windns)
    provides a compatible subset of this package'\''s API.

category:             Network
abi:                  9023652439f090f819a60de5dfc7a6cf
exposed:              True
exposed-modules:      Network.DNS
hidden-modules:       Network.DNS.Message Network.DNS.FFI Compat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/resolv-0.2.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/resolv-0.2.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/resolv-0.2.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-resolv
hs-libraries:         HSresolv-0.2.0.3-6GogbJI66nX3ijEU5qmLzY
depends:
    base-4.17.2.1 base16-bytestring-1.0.2.0-Eyzq7m0xe67GiRftjHundc
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7

haddock-interfaces:   /usr/share/doc/haskell-resolv/html/resolv.haddock
haddock-html:         /usr/share/doc/haskell-resolv/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
